searchData={"items":[{"type":"module","title":"TailwindFormatter","doc":"Opinionated sorting for [TailwindCSS](https://tailwindcss.com)\nclasses used in HEEx templates and `~H` sigils.\n\n`TailwindFormatter` is a `mix format` [plugin](https://hexdocs.pm/mix/main/Mix.Tasks.Format.html#module-plugins)\nthat sorts TailwindCSS classes found in your templates. It takes\ninspiration from Tailwind's official [Prettier plugin](https://tailwindcss.com/blog/automatic-class-sorting-with-prettier).\n\n> Note: This formatter requires Elixir v1.15 or later.","ref":"TailwindFormatter.html"},{"type":"module","title":"Installation - TailwindFormatter","doc":"Add `tailwind_formatter` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:tailwind_formatter, \"~> 0.4.0\", only: [:dev, :test], runtime: false}\n  ]\nend\n```","ref":"TailwindFormatter.html#module-installation"},{"type":"module","title":"Setup - TailwindFormatter","doc":"`TailwindFormatter` is most likely to be used alongside `Phoenix.LiveView.HTMLFormatter`,\nso it should be installed in a way that allows the HTML formatter to\nrun after the Tailwind formatter. \n\nUpdate your `.formatter.exs` to include `TailwindFormatter`.\n\n```elixir\n  [\n    plugins: [TailwindFormatter, Phoenix.LiveView.HTMLFormatter],\n    inputs: [\n      \"*.{heex,ex,exs}\",\n      \"priv/*/seeds.exs\",\n      \"{config,lib,test}/**/*.{heex,ex,exs}\"\n    ],\n    # ...\n  ]\n```","ref":"TailwindFormatter.html#module-setup"},{"type":"module","title":"Using Custom TailwindCSS configuration - TailwindFormatter","doc":"If you are using the standalone tailwind module, you can append these lines to the end of your `tailwind.config.js` file:\n\n```js\nlet { extract } = require(\"../deps/tailwind_formatter/assets/js\")\nextract(module.exports, \"../_build\")\n```\n\nThis will write a `classes.txt` and `variants.txt` to your `_build/` directory. \nThe second argument within `extract` may vary depending on the value of `cd:` in your `:tailwind` config. \n\nThe above will work with this configuration, for example:\n\n```elixir\n  config :tailwind,\n    version: \"3.3.3\",\n    default: [\n      args: ~w(\n      --config=tailwind.config.js\n      --input=css/app.css\n      --output=../_build/assets/out.css\n    ),\n      cd: Path.expand(\"../assets\", __DIR__)\n    ]\n```\n\nRun `mix tailwind default` to force it to extract the configuration.\n\nAfterward, when you run `mix compile` you should see TailwindFormatter loading in your custom classes.\nIf you don't, you can run `mix deps.compile tailwind_formatter --force`.\n\n```bash\n❯ mix deps.compile tailwind_formatter --force\n==> tailwind_formatter\nCompiling 5 files (.ex)\nLoading in /path/to/repo/_build/classes.txt.\nLoading in /path/to/repo/_build/variants.txt.\nGenerated tailwind_formatter app\n```","ref":"TailwindFormatter.html#module-using-custom-tailwindcss-configuration"},{"type":"module","title":"Usage - TailwindFormatter","doc":"After installation and setup, run `mix format`. If you already had\nautomatic formatting set up (for instance, if your editor is configured\nto format your code on save), no changes should be required! Your\nTailwind classes should be happily organized going forward!\n\nIf some files are not being formatted as expected, double-check the\n`:inputs` option in your `.formatter.exs` to ensure they are being\nmatched.","ref":"TailwindFormatter.html#module-usage"},{"type":"module","title":"Formatting - TailwindFormatter","doc":"The formatter aims to follow a bundle of rules outlined in the [blog post](https://tailwindcss.com/blog/automatic-class-sorting-with-prettier)\nthat introduced the official Tailwind Prettier plugin.\n\n- Order classes the same way they are imported in the CSS file: Base, Components, Utilities\n- Classes that override other classes appear later in the list\n- Classes that impact layout take precedence over classes that decorate\n- Plain classes come first before variants (i.e. `focus:`)\n- Unknown classes are sorted to the front","ref":"TailwindFormatter.html#module-formatting"},{"type":"module","title":"How it diverges from the original formatter - TailwindFormatter","doc":"There are some differences in order to simplify the algorithm and to support Elixir use cases.\n\n#","ref":"TailwindFormatter.html#module-how-it-diverges-from-the-original-formatter"},{"type":"module","title":"Inline elixir functions are sorted toward the front - TailwindFormatter","doc":"With elixir templating one may add an `#{inline_elixir_function}` to the class list.\nThe formatter supports this and sorts these toward the front.\n\n#","ref":"TailwindFormatter.html#module-inline-elixir-functions-are-sorted-toward-the-front"},{"type":"module","title":"Variants are always grouped, even if the class is unknown - TailwindFormatter","doc":"i.e. `sm:unknown-class` will still be grouped with the other `sm:` variants, even if Tailwind doesn't recognize the class.\n\n#","ref":"TailwindFormatter.html#module-variants-are-always-grouped-even-if-the-class-is-unknown"},{"type":"module","title":"Variant order is enforced - TailwindFormatter","doc":"In the original spec, 'variants' i.e. `sm:hover:` are sorted as though it is one block.\nThus, the order in which they're specified does not matter.\nSo, for example, a chain of `dark:sm:hover:text-gray-600` would be placed toward the end.\n\nIn this algorithm, classes are sorted by \"layers\".\nAll `sm:` variants are grouped together, even if it's a chain of 4 variants.\nSo for example, `dark:sm:hover:text-gray-600` will be placed before any `sm:` and `hover:` variants, because `dark:` has precedence over `sm:` and `hover:`.\n\nThus in order to achieve more consistency, the variant chain is ordered.\nSo, `dark:sm:hover:text-gray-600` transforms to `sm:dark:hover:text-gray-600`.\n\n#","ref":"TailwindFormatter.html#module-variant-order-is-enforced"},{"type":"module","title":"Dynamically rendered classes - TailwindFormatter","doc":"Sometimes you may want to dynamically render a class depending on a variable,\ni.e. `lg:grid-cols-#{@cols}` or `alert alert-#{@type}`. The formatter supports\nthis, and also sorts these toward the front of the variant group it is within.\n\nNote: you will need to define the full class either within the Tailwind\n[safelist](https://tailwindcss.com/docs/content-configuration#safelisting-classes)\nor have it fully written out somewhere else in the source file.\n\nSo, for example, if `@cols = 5` within `grid-cols-#{@cols}`, then you will need\n`grid-cols-5` written in full somewhere in the source so Tailwind won't purge it\nin production.","ref":"TailwindFormatter.html#module-dynamically-rendered-classes"},{"type":"module","title":"Credits - TailwindFormatter","doc":"This project builds heavily off of [rustywind](https://github.com/avencera/rustywind)\nand [HTMLFormatter](https://hexdocs.pm/phoenix_live_view/Phoenix.LiveView.HTMLFormatter.html).","ref":"TailwindFormatter.html#module-credits"},{"type":"function","title":"TailwindFormatter.features/1","doc":"","ref":"TailwindFormatter.html#features/1"},{"type":"function","title":"TailwindFormatter.format/2","doc":"","ref":"TailwindFormatter.html#format/2"},{"type":"extras","title":"Changelog for v0.4.0","doc":"# Changelog for v0.4.0\n\nTailwindFormatter v0.4.0 requires Elixir v1.15+.","ref":"changelog.html"},{"type":"extras","title":"Removing TailwindFormatter.MultiFormatter - Changelog for v0.4.0","doc":"The above was a stop-gap due to earlier versions of Elixir not supporting multiple formatters in your `.formatter.exs`.\n\nThis is no longer the case for Elixir v1.15. Since TailwindFormatter now requires 1.15 and above, this module has been removed.\n\nYour `.formatter.exs` should instead look like this:\n\n```elixir\n  [\n    plugins: [TailwindFormatter, Phoenix.LiveView.HTMLFormatter],\n    # ...\n  ]\n```","ref":"changelog.html#removing-tailwindformatter-multiformatter"},{"type":"extras","title":"Support for class lists - Changelog for v0.4.0","doc":"TailwindFormatter v0.4.0 now supports class lists like so:\n\n```elixir\n     \n```\n\nThis was achieved by switching our parsing strategy to `Phoenix.LiveView.Tokenizer`.","ref":"changelog.html#support-for-class-lists"},{"type":"extras","title":"Sorting string fragments within elixir expressions - Changelog for v0.4.0","doc":"If you have a string fragment with a couple of classes, such as:\n\n```elixir\n\"#{if true, do: \"px-1 bg-white shadow-md\"}\"\n```\n\nthe fragment will be sorted as well.","ref":"changelog.html#sorting-string-fragments-within-elixir-expressions"},{"type":"extras","title":"Custom Tailwind configuration support - Changelog for v0.4.0","doc":"Previously TailwindFormatter could only use a dump of default classes and variants from Tailwind. \nNow you can extract your custom classes by injecting two lines into your `tailwind.config.js`.\n\n```js\nlet { extract } = require(\"../deps/tailwind_formatter/assets/js\")\nextract(module.exports, \"../_build\")\n```\n\nThis will extract all the classes and variants you are using which TailwindFormatter will use to sort your classes.","ref":"changelog.html#custom-tailwind-configuration-support"},{"type":"extras","title":"0.4.0 (2023-10-24) - Changelog for v0.4.0","doc":"- Bump Elixir version to 1.15\n- Remove MultiFormatter as Elixir now supports multiple formatters\n- Switch to Phoenix.LiveView.Tokenizer to grab class attributes\n- Supports array class lists\n- Preserves leading & trailing spaces between expression fragments\n- Supports custom TailwindCSS configuration using standalone CLI","ref":"changelog.html#0-4-0-2023-10-24"}],"content_type":"text/markdown"}